View source: R/confints.bootpls.R
| confints.bootpls | R Documentation |
This function is a wrapper for boot.ci to derive
bootstrap-based confidence intervals from a "boot" object.
confints.bootpls(bootobject, indices = NULL, typeBCa = TRUE)
bootobject |
an object of class |
indices |
the indices of the predictor for which CIs should be
calculated. Defaults to |
typeBCa |
shall BCa bootstrap based CI derived ? Defaults to
|
Matrix with the limits of bootstrap based CI for all (defaults) or
only the selected predictors (indices option). The limits are given
in that order: Normal Lower then Upper Limit, Basic Lower then Upper Limit,
Percentile Lower then Upper Limit, BCa Lower then Upper Limit. Column names
are added so that the returned matrix can be reused by downstream helpers
such as confints2signifind.
Frédéric Bertrand
frederic.bertrand@lecnam.net
https://fbertran.github.io/homepage/
See also bootpls and bootplsglm.
data(Cornell)
#Lazraq-Cleroux PLS (Y,X) bootstrap
set.seed(250)
modpls <- plsR(Y~.,data=Cornell,3)
Cornell.bootYX <- bootpls(modpls, R=250, verbose=FALSE)
confints.bootpls(Cornell.bootYX,2:8)
confints.bootpls(Cornell.bootYX,2:8,typeBCa=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.