The caterpillar dataset was extracted from a 1973 study on pine processionary caterpillars. It assesses the influence of some forest settlement characteristics on the development of caterpillar colonies. There are k=10 potentially explanatory variables defined on n=33 areas. The value of x2 for the first observation was removed from the matrix of predictors on purpose.
data(pineNAX21)A data frame with 33 observations on the following 11 variables and one missing value.
x1altitude (in meters)
x2slope (en degrees)
x3number of pines in the area
x4height (in meters) of the tree sampled at the center of the area
x5diameter (in meters) of the tree sampled at the center of the area
x6index of the settlement density
x7orientation of the area (from 1 if southbound to 2 otherwise)
x8height (in meters) of the dominant tree
x9number of vegetation strata
x10mix settlement index (from 1 if not mixed to 2 if mixed)
x11logarithmic transform of the average number of nests of caterpillars per tree
These caterpillars got their names from their habit of moving over the ground in incredibly long head-to-tail processions when leaving their nest to create a new colony.
The pineNAX21 is a dataset with a missing value for testing purpose.
# NOT RUN {
data(pineNAX21)
str(pineNAX21)
# }
Run the code above in your browser using DataLab