Learn R Programming

plsRglm (version 1.7.1)

plsRglm-package: plsRglm: Partial Least Squares Regression for Generalized Linear Models

Description

logo

Provides (weighted) Partial least squares Regression for generalized linear models and repeated k-fold cross-validation of such models using various criteria tools:::Rd_expr_doi("10.48550/arXiv.1810.01005"). It allows for missing data in the explanatory variables. Bootstrap confidence intervals constructions are also available.

Arguments

Author

Maintainer: Frederic Bertrand frederic.bertrand@lecnam.net (ORCID)

Authors:

References

A short paper that sums up some of features of the package is available on https://arxiv.org/, Frédéric Bertrand and Myriam Maumy-Bertrand (2018), "plsRglm: Partial least squares linear and generalized linear regression for processing incomplete datasets by cross-validation and bootstrap techniques with R", *arxiv*, https://arxiv.org/abs/1810.01005, https://github.com/fbertran/plsRglm/ et https://fbertran.github.io/plsRglm/

See Also

Examples

Run this code
set.seed(314)
library(plsRglm)
data(Cornell)
cv.modpls<-cv.plsR(Y~.,data=Cornell,nt=6,K=6)
res.cv.modpls<-cvtable(summary(cv.modpls))

Run the code above in your browser using DataLab