plsRmulti() implements an experimental complete-case linear PLS2 fit for
multivariate numeric responses. It is intentionally separate from
plsR so the current PLS1 API remains unchanged.
plsRmulti(object, ...)# S3 method for default
plsRmultiModel(
object,
dataX,
nt = 2,
limQ2set = 0.0975,
dataPredictY,
modele = "pls",
family = NULL,
typeVC = "none",
EstimXNA = FALSE,
scaleX = TRUE,
scaleY = NULL,
pvals.expli = FALSE,
alpha.pvals.expli = 0.05,
MClassed = FALSE,
tol_Xi = 10^(-12),
weights,
sparse = FALSE,
sparseStop = FALSE,
naive = FALSE,
verbose = TRUE,
...
)
# S3 method for formula
plsRmultiModel(
object,
data,
nt = 2,
limQ2set = 0.0975,
modele = "pls",
family = NULL,
typeVC = "none",
EstimXNA = FALSE,
scaleX = TRUE,
scaleY = NULL,
pvals.expli = FALSE,
alpha.pvals.expli = 0.05,
MClassed = FALSE,
tol_Xi = 10^(-12),
weights,
subset,
contrasts = NULL,
sparse = FALSE,
sparseStop = FALSE,
naive = FALSE,
verbose = TRUE,
...
)
An object of class "plsRmultiModel" with multivariate analogues of the
linear plsR outputs, including the extracted scores tt, X
loadings pp, response score coefficients CoeffC, coefficient
matrix Coeffs, intercept vector CoeffConstante, scaled response
matrix RepY, and fitted response matrices YChapeau,
Std.ValsPredictY, and ValsPredictY.
For the default method, a numeric multivariate response matrix
or data frame with at least two columns. For the formula method, a formula of
the form cbind(y1, y2, ...) ~ ..
Not used. Extra arguments are rejected in this experimental release.
Numeric predictor matrix or data frame.
Number of components to extract.
Kept for interface compatibility. Not supported by
plsRmulti.
Kept for interface compatibility. Not supported by
plsRmulti; fit first and then use predict.
Only "pls" is supported.
Not supported in this experimental release.
Only "none" is supported.
Not supported in this experimental release.
Should predictors be scaled?
Should responses be scaled? Defaults to TRUE.
Not supported in this experimental release.
Not supported in this experimental release.
Not supported in this experimental release.
Tolerance used for degeneracy checks during component extraction.
Not supported in this experimental release.
Not supported in this experimental release.
Not supported in this experimental release.
Not supported in this experimental release.
Should informational messages be displayed?
An optional data frame for the formula method.
An optional subset for the formula method.
Optional contrasts for the formula method.
This experimental release supports complete-case linear PLS2 fitting,
prediction, repeated k-fold cross-validation via cv.plsRmulti,
and bootstrap resampling via bootpls. It still does not support
missing values, weights, sparse extraction, classification diagnostics, or GLM
families.
predict.plsRmultiModel, cv.plsRmulti,
bootpls, plsR
set.seed(123)
X <- matrix(rnorm(60 * 4), ncol = 4)
Y <- cbind(
y1 = X[, 1] - 0.5 * X[, 2] + rnorm(60, sd = 0.1),
y2 = 0.3 * X[, 2] + X[, 3] + rnorm(60, sd = 0.1)
)
fit <- plsRmulti(Y, X, nt = 2, verbose = FALSE)
fit
head(predict(fit))
Run the code above in your browser using DataLab