View source: R/summary.cv.plsRmultiModel.R
| summary.cv.plsRmultiModel | R Documentation |
Summarizes repeated k-fold cross-validation results from
cv.plsRmulti.
## S3 method for class 'cv.plsRmultiModel'
summary(object, verbose = TRUE, ...)
object |
An object of class |
verbose |
Should progress information be displayed? |
... |
Further arguments passed to methods. |
The returned object inherits from "summary.cv.plsRmodel" so that
cvtable and the existing plot method can be reused for the
aggregated multivariate criteria.
A list of per-partition summary matrices with the same aggregate columns used
by summary.cv.plsRmodel for Q2, PRESS, and
RSS, plus response-specific PRESS, RSS, Q2, and
R2 columns.
cv.plsRmulti, cvtable
set.seed(123)
X <- matrix(rnorm(60 * 4), ncol = 4)
Y <- cbind(
y1 = X[, 1] - 0.5 * X[, 2] + rnorm(60, sd = 0.1),
y2 = 0.3 * X[, 2] + X[, 3] + rnorm(60, sd = 0.1)
)
cv_fit <- cv.plsRmulti(Y, X, nt = 2, K = 3, NK = 1, verbose = FALSE)
summary(cv_fit, verbose = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.